Enum VmCap

pub enum VmCap {
    DirtyLog,
    PvClock,
    Protected,
    EarlyInitCpuid,
    BusLockDetect,
    ReadOnlyMemoryRegion,
    MemNoncoherentDma,
}
A capability the Vm can possibly expose.

Variants



DirtyLog

Track dirty pages



PvClock

Paravirtualized clock device



Protected

VM can be run in protected mode, where the host does not have access to its memory.



EarlyInitCpuid

VM completes initialization of CPUID at creation time, not required after.



BusLockDetect

VM can detect the bus lock



ReadOnlyMemoryRegion

Supports read-only memory regions.



MemNoncoherentDma

VM can set guest memory cache noncoherent DMA flag