Enum BalloonEvent

pub enum BalloonEvent {
    Inflate(MemRegion),
    Deflate(MemRegion),
    BalloonTargetReached(u64),
}
This is intended for use with virtio-balloon, where a guest driver determines unused ranges and requests they be freed. Use without the guest’s knowledge is sure to break something.

Variants



Inflate(MemRegion)

Balloon event when the region is acquired from the guest. The guest cannot access this region any more. The guest memory can be reclaimed by the host OS. As per virtio-balloon spec, the given address and size are intended to be page-aligned.



Deflate(MemRegion)

Balloon event when the region is returned to the guest. VMM should reallocate memory and register it with the hypervisor for accesses by the guest.



BalloonTargetReached(u64)

Balloon event when the requested memory size is achieved. This can be achieved through either inflation or deflation. The u64 will be the current size of the balloon in bytes.