pub enum IoOperation<'a> {
Read(&'a mut [u8]),
Write(&'a [u8]),
}Expand description
Operation for Io and Mmio
Variants
Read(&'a mut [u8])
Data to be read from a device on the bus.
The handle_fn should fill the entire slice with the read data.
Write(&'a [u8])
Data to be written to a device on the bus.