#[repr(C)]pub enum MPState {
Runnable = 0,
Uninitialized = 1,
InitReceived = 2,
Halted = 3,
SipiReceived = 4,
Stopped = 5,
}Expand description
The MPState represents the state of a processor.
Variants
Runnable = 0
the vcpu is currently running (x86/x86_64,arm/arm64)
Uninitialized = 1
the vcpu is an application processor (AP) which has not yet received an INIT signal (x86/x86_64)
InitReceived = 2
the vcpu has received an INIT signal, and is now ready for a SIPI (x86/x86_64)
Halted = 3
the vcpu has executed a HLT instruction and is waiting for an interrupt (x86/x86_64)
SipiReceived = 4
the vcpu has just received a SIPI (vector accessible via KVM_GET_VCPU_EVENTS) (x86/x86_64)
Stopped = 5
the vcpu is stopped (arm/arm64)