pub enum ProtectionType {
Unprotected,
Protected,
ProtectedWithCustomFirmware,
ProtectedWithoutFirmware,
UnprotectedWithFirmware,
}Expand description
Whether the VM should be run in protected mode or not.
Variants
Unprotected
The VM should be run in the unprotected mode, where the host has access to its memory.
Protected
The VM should be run in protected mode, so the host cannot access its memory directly. It should be booted via the protected VM firmware, so that it can access its secrets.
ProtectedWithCustomFirmware
The VM should be run in protected mode, so the host cannot access its memory directly. It should be booted via a custom VM firmware, useful for debugging and testing.
ProtectedWithoutFirmware
The VM should be run in protected mode, but booted directly without pVM firmware. The host will still be unable to access the VM memory, but it won’t be given any secrets.
UnprotectedWithFirmware
The VM should be run in unprotected mode, but with the same memory layout as protected mode, protected VM firmware loaded, and simulating protected mode as much as possible. This is useful for debugging the protected VM firmware and other protected mode issues.
Implementations
Sourceimpl ProtectionType
impl ProtectionType
Sourcepub fn isolates_memory(&self) -> bool
pub fn isolates_memory(&self) -> bool
Returns whether the hypervisor will prevent us from accessing the VM’s memory.
Sourcepub fn needs_firmware_loaded(&self) -> bool
pub fn needs_firmware_loaded(&self) -> bool
Returns whether the VMM needs to load the pVM firmware.
Sourcepub fn runs_firmware(&self) -> bool
pub fn runs_firmware(&self) -> bool
Returns whether the VM runs a pVM firmware.