pub struct VcpuShutdownError {
pub(crate) kind: VcpuShutdownErrorKind,
pub(crate) raw_error_code: u64,
}Expand description
A Vcpu shutdown may signify an error, such as a double or triple fault, or hypervisor specific reasons. This error covers all such cases.
Fields
kind: VcpuShutdownErrorKindraw_error_code: u64Implementations
Sourceimpl VcpuShutdownError
impl VcpuShutdownError
pub fn new( kind: VcpuShutdownErrorKind, raw_error_code: u64, ) -> VcpuShutdownError
pub fn kind(&self) -> VcpuShutdownErrorKind
pub fn get_raw_error_code(&self) -> u64