Enum PitRWMode

#[repr(C)]
pub enum PitRWMode { None = 0, Least = 1, Most = 2, Both = 3, }
The PitRWMode enum represents the access mode of a PIT channel. Reads and writes to the Pit happen over Port-mapped I/O, which happens one byte at a time, but the count values and latch values are two bytes. So the access mode controls which of the two bytes will be read when.

Variants



None = 0

None mode means that no access mode has been set.



Least = 1

Least mode means all reads/writes will read/write the least significant byte.



Most = 2

Most mode means all reads/writes will read/write the most significant byte.



Both = 3

Both mode means first the least significant byte will be read/written, then the next read/write will read/write the most significant byte.

Implementations

Source

impl PitRWMode

pub fn n<REPR: Into<i64>>(value: REPR) -> Option<Self>