#[repr(C)]pub struct PitChannelState {Show 13 fields
pub count: u32,
pub latched_count: u16,
pub count_latched: PitRWState,
pub status_latched: bool,
pub status: u8,
pub read_state: PitRWState,
pub write_state: PitRWState,
pub reload_value: u16,
pub rw_mode: PitRWMode,
pub mode: u8,
pub bcd: bool,
pub gate: bool,
pub count_load_time: u64,
}Expand description
The PitChannelState represents the state of one of the PIT’s three counters.
Fields
count: u32The starting value for the counter.
latched_count: u16Stores the channel count from the last time the count was latched.
count_latched: PitRWStateIndicates the PitRWState state of reading the latch value.
status_latched: boolIndicates whether ReadBack status has been latched.
status: u8Stores the channel status from the last time the status was latched. The status contains information about the access mode of this channel, but changing those bits in the status will not change the behavior of the pit.
read_state: PitRWStateIndicates the PitRWState state of reading the counter.
write_state: PitRWStateIndicates the PitRWState state of writing the counter.
reload_value: u16Stores the value with which the counter was initialized. Counters are 16- bit values with an effective range of 1-65536 (65536 represented by 0).
rw_mode: PitRWModeThe command access mode of this channel.
mode: u8The operation mode of this channel.
bcd: boolWhether or not we are in bcd mode. Not supported by KVM or crosvm’s PIT implementation.
gate: boolValue of the gate input pin. This only applies to channel 2.
count_load_time: u64Nanosecond timestamp of when the count value was loaded.