Module hypervisor::osx
[−]
[src]
Hypervisor API for OSX
To use this, you need
- OS X Yosemite (10.10) or newer
- an Intel processor with the VT-x feature set that includes Extended Page Tables (EPT) and Unrestricted Mode
To verify if the latter is true, run and expect the following in the Terminal:
$ sysctl kern.hv_support
kern.hv_support: 1
Modules
| ffi |
Bindings to the Hypervisor Framework |
Structs
| vCPU |
Virtual CPU |
Enums
| Error |
Error returned after every call |
Functions
| create_vm |
Creates a VM instance for the current task |
| destory_vm |
Destroys the VM instance associated with the current task |